@@ -1,5 +1,5 @@
 """Urls for the ``object_events`` app."""
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 
 from .views import ObjectEventsMarkView, ObjectEventsListView
 
